/*---------------------------------------------------------------------------*\

    FILE....: MAPDEV.CPP
    TYPE....: WIN32 C++ Function
    AUTHOR..: John Kostogiannis
    DATE....: 6/11/97

    Functions used to map the board and channel number to a handle and 
	vice versa.

\*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*\

         Voicetronix Voice Processing Board (VPB) Software

         Copyright (C) 1999-2001 Voicetronix www.voicetronix.com.au

         This library is free software; you can redistribute it and/or
         modify it under the terms of the GNU Lesser General Public
         License as published by the Free Software Foundation; either
         version 2.1 of the License, or (at your option) any later version.

         This library is distributed in the hope that it will be useful,
         but WITHOUT ANY WARRANTY; without even the implied warranty of
         MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
         Lesser General Public License for more details.

         You should have received a copy of the GNU Lesser General Public
         License along with this library; if not, write to the Free Software
         Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
	 USA

\*---------------------------------------------------------------------------*/

#include <assert.h>
#include <stdlib.h>
#include <stdio.h>

#include "wobbly.h"
#include "mapdev.h"
#include "apifunc.h"
#include "mess.h"

#ifdef _OPENPRI
 #include "openpri.h"
#endif

/*--------------------------------------------------------------------------*\

	FUNCTION.: mapdevtohndle
	AUTHOR...: John Kostogiannis
	DATE.....: 25/11/97

	Maps the board number and channel number to a handle, this function
	assumes four channels per board.

\*--------------------------------------------------------------------------*/

int mapdevtohndle(USHORT brdnum, USHORT chnum)
{
	int handle;
	VPBREG * v = vpb_c->vpbreg(brdnum);
	VPBHANDLE * h = vpb_c->vpbhandles();
	handle = v->handle[chnum];
	if (handle == -1){
//		mprintf("Un-allocated, allocating handle to chan[%d] board[%d]\n",chnum,brdnum);
		handle = vpb_c->get_next_handle();
		h[handle].channel=chnum;
		h[handle].board=brdnum;
		v->handle[chnum]=handle;
	}
	return(handle);
/*
	int model=vpb_c->vpbreg(brdnum)->model;
	switch(model) {
	case VPB_VPB4:
		assert(chnum < 4);
		handle = brdnum<<2;
		handle	+= chnum;
		break;
	case VPB_VPB8L:
		assert(chnum < 8);
		handle = brdnum<<3;
		handle	+= chnum;
		break;
	case VPB_V12PCI:
		assert(chnum < 12);
		handle = brdnum*12 + chnum;
		break;
	case VPB_PRI:
		assert(chnum < 32);
		handle = chnum;
		break;
	default:
		assert(0);
	}
	return(handle);
*/
}

/*--------------------------------------------------------------------------*\

	FUNCTION.: maphndletodev
	AUTHOR...: John Kostogiannis
	DATE.....: 25/11/97

	Maps the handle to board number and channel number.  This function
	assumes four channels per board.

\*--------------------------------------------------------------------------*/

void maphndletodev(int hndle, USHORT *brdnum, USHORT *chnum)
{
	int ch,bd;
	VPBHANDLE * h = vpb_c->vpbhandles();
	ch = h[hndle].channel;
	bd = h[hndle].board;
	if ((ch < 0) || (bd < 0)){
		assert(0);
	}
	else {
		*brdnum=(USHORT)bd;
		*chnum=(USHORT)ch;
	}
	return;
/*
	switch(model) {
	case VPB_VPB4:
		*brdnum = hndle & 0xfffc;
		*brdnum = *brdnum>>2;
		*chnum = hndle & 0x3;
		break;
	case VPB_VPB8L:
		*brdnum = hndle & 0xfff8;
		*brdnum = *brdnum>>3;
		*chnum = hndle & 0x7;
		break;
	case VPB_V12PCI:
		*brdnum = hndle / 12;
		*chnum = hndle % 12;
		break;
	case VPB_PRI:
		*brdnum = hndle / 32;
		*chnum = (hndle % 32);
		break;
	default:
		assert(0);
	}
*/
}


#ifdef _OPENPRI
/*--------------------------------------------------------------------------*\

	FUNCTION.: get_idx_from_ch()
	AUTHOR...: Ben Kramer
	DATE.....: xx/12/04
	
	Finds out the index to chans given a vpb channel

\*--------------------------------------------------------------------------*/
int get_idx_from_ch(VPBREG *v, int ch)
{
	pri_chan *chans = (pri_chan*)v->chans;
	int i = 0;

	for(; i < v->numch; ++i){
		if(ch == chans[i].chan_num)
			return i;
	}
	throw Wobbly(MAPDEV_INVALID_CHANNEL);
}

/*--------------------------------------------------------------------------*\

	FUNCTION.: get_idx_from_ich()
	AUTHOR...: Ben Kramer
	DATE.....: xx/01/05
	
	Finds out the index to chans given an ISDN channel

\*--------------------------------------------------------------------------*/
int get_idx_from_ich(VPBREG *v, int ch)
{
	pri_chan *chans = (pri_chan *)v->chans;
	int i = 0;

	ch &= 0xff;     // strip off any extra flags added by libpri.
	for(; i < v->numch; ++i){
		if(ch == chans[i].iface->channel)
			return i;
	}
	throw Wobbly(MAPDEV_INVALID_CHANNEL);
}
#endif

